export type Detective = (contents: string) => string[];
export type Extensions = {
    [extension: string]: Detective | undefined;
};
export type CheckOptions = {
    path: string;
    entries?: string[] | undefined;
    noDefaultEntries?: boolean | undefined;
    extensions?: string[] | Extensions | undefined;
    detective?: string | Detective | undefined;
    builtins?: boolean | undefined;
};
export type DependencyOptions = {
    excludeDev?: boolean | undefined;
    excludePeer?: boolean | undefined;
    ignore?: string | string[] | undefined;
};
export type ResolveDefaultEntriesPathsOptions = {
    path: string;
    package: import('type-fest').PackageJson;
};
export type ResolvePathsOptions = {
    path: string;
    package: import('type-fest').PackageJson;
    noDefaultEntries: undefined | boolean;
    entries: undefined | string[];
};
export type DependencyContext = {
    deps: Set<string>;
    seen: Set<string>;
    core: Set<string>;
};
export type ParseOptions = {
    path: string;
    package: import('type-fest').PackageJson;
    extensions: Extensions;
    builtins: undefined | boolean;
    noDefaultEntries: undefined | boolean;
    entries: undefined | string[];
};
export type ParseResult = {
    package: import('type-fest').PackageJson;
    used: string[];
    builtins?: string[] | undefined;
};
/**
 * @typedef CheckOptions
 * @property {string} path
 * @property {string[]} [entries]
 * @property {boolean} [noDefaultEntries]
 * @property {Extensions|string[]} [extensions]
 * @property {Detective|string} [detective]
 * @property {boolean} [builtins]
 */
/**
 * @param {CheckOptions} opts
 * @returns {Promise<ParseResult>}
 */
export function check({ builtins, detective, entries, extensions, noDefaultEntries, path: targetPath }: CheckOptions): Promise<ParseResult>;
/**
 * @param {import('type-fest').PackageJson} pkg
 * @param {string[]} deps
 * @param {DependencyOptions} [options]
 * @returns {string[]}
 */
export function extra(pkg: import('type-fest').PackageJson, deps: string[], options?: DependencyOptions | undefined): string[];
/**
 * @param {import('type-fest').PackageJson} pkg
 * @param {string[]} deps
 * @param {DependencyOptions} [options]
 * @returns {string[]}
 */
export function missing(pkg: import('type-fest').PackageJson, deps: string[], options?: DependencyOptions | undefined): string[];
